@@ -1,7 +1,7 @@
 setMethodS3("getChecksum", "Object", function(object, ...) {
   object <- clearCache(object);
-  NextMethod("getChecksum", object, ...);
-})
+  NextMethod("getChecksum", object);
+}, export=FALSE)
 
 
 ############################################################################
