@@ -15,7 +15,7 @@
 #
 # \arguments{
 #   \item{object}{The object for which a checksum should be calculated.}
-#   \item{...}{Not used.}
+#   \item{...}{Additional arguments passed to @see "digest::digest".}
 # }
 #
 # \value{
@@ -23,13 +23,13 @@
 # }
 #
 # \details{
-#   Because \code{getChecksum()} is a generic function, 
+#   Because \code{getChecksum()} is a generic function,
 #   it is possible to provide custom methods for specific
 #   classes of objects.  This means that, if a certain class
 #   specifies fields that carry auxillary data, then these
 #   can be excluded from the checksum calculation.
 #   For instance, assume that all objects of class 'TimestampedObject'
-#   contain timestamps specifying when each object was created. 
+#   contain timestamps specifying when each object was created.
 #   Then a custom \code{getChecksum()} method for this class can
 #   first drop the timestamp and then call the default
 #   \code{getChecksum()} function.
@@ -38,21 +38,23 @@
 # @author
 #
 # \seealso{
-#   By default, the @see "digest::digest" method is used to calculate
+#   Internally, the @see "digest::digest" method is used to calculate
 #   the checksum.
 # }
 #
 # @keyword "programming"
 # @keyword "IO"
 # @keyword "internal"
-#*/######################################################################### 
+#*/#########################################################################
 setMethodS3("getChecksum", "default", function(object, ...) {
-  digest::digest(object);
+  digest::digest(object, ...);
 })
 
 
 ############################################################################
 # HISTORY:
+# 2013-07-03
+# o Now getChecksum() passes '...' to digest(), e.g. argument 'algo'.
 # 2012-11-17
 # o CLEANUP: Removed a require("digest") to avoid loaded the package,
 #   and instead call digest::digest().
